@@ -1,6 +1,7 @@
 #Null models for community data
 #Internal use only; mostly based on picante's code
 #' @importFrom picante randomizeMatrix
+#' @export
 .eco.null <- function(comm, method=c("taxa.labels", "richness", "frequency", "independentswap", "trialswap"), swap.iter=1000){
   #Checks
   method <- match.arg(method)
@@ -13,6 +14,7 @@
 }
 
 #Prearing regressions for output
+#' @importFrom stats coef
 .prepare.regression.output <- function(observed, randomisations=NULL, method=c("lm", "quantile", "mantel"), permute=0, class=NULL){
   #Checks
   method <- match.arg(method)
@@ -53,6 +55,7 @@
 #' @export
 #' @rdname eco.xxx.regression
 #' @importFrom quantreg summary.rq print.rq
+#' @importFrom stats sd
 summary.eco.xxx.regression <- function(object, ...){
     x <- object  ## FIXME:  lazy hack
     cat("\n", x$type, "\n", sep="")
@@ -86,6 +89,8 @@ print.eco.xxx.regression <- function(x, ...){
     summary(x, ...)
 }
 
+#' @importFrom graphics plot abline
+#' @importFrom stats coef
 .plot.regression <- function(x, y, observed, randomisations,
                              method=c("quantile", "lm", "mantel"),
                              permute=0, ...){
@@ -119,6 +124,8 @@ print.eco.xxx.regression <- function(x, ...){
 #' @method plot eco.xxx.regression
 #' @export
 #' @rdname eco.xxx.regression
+#' @importFrom stats as.dist
+#' @importFrom ape cophenetic.phylo
 plot.eco.xxx.regression <- function(x, ...){
     if(x$type == "eco.env.regression"){
         #Beware calling without knowing which environmental distance matrix we should be using
@@ -140,7 +147,7 @@ plot.eco.xxx.regression <- function(x, ...){
 
     if(x$type == "eco.phy.regression"){
         eco.matrix <- as.numeric(comm.dist(x$data$comm))
-        phy.matrix <- as.numeric(as.dist(cophenetic(x$data$phy)))
+        phy.matrix <- as.numeric(as.dist(cophenetic.phylo(x$data$phy)))
         .plot.regression(phy.matrix, eco.matrix, x$observed, x$randomisations, x$method, x$permute,
                          xlab="Phylogenetic Distance", ylab="Ecological Co-existnce", ...)
     }
@@ -243,142 +250,6 @@ plot.eco.xxx.regression.list <- function(x, ...){
 drop_tip <- function(tree, spp)
   if(length(setdiff(tree$tip.label, spp)) >0) return(drop.tip(tree, spp)) else return(tree)
 
-#' @method summary phy.structure
-#' @export
-summary.phy.structure <- function(object, ...){
-    #Argument checking
-    if(!inherits(object, "phy.structure"))
-        stop("'", substitute(deparse(object)), "' not of class 'phy.structure'")
-    
-    #Shape
-    if(object$type == "shape"){
-        cat("\nShape metrics in this object:\n")
-        if(!is.null(object$psv))
-            cat("\tPSV (psv)\n")
-        if(!is.null(object$psr))
-            cat("\tPSR (psr)\n")
-        if(!is.null(object$mpd))
-            cat("\tMean Phylogenetic Distance (mpd)\n")
-        if(!is.null(object$mntd))
-            cat("\tMean Mean Nearest Taxon Distance (mntd)\n")
-        if(!is.null(object$pd))
-            cat("\tPhylogenetic Distance (pd)\n")
-        if(!is.null(object$pd.ivs))
-            cat("\tPhylogenetic Distance stanardised according to number of species in sample (pd.ivs)\n")
-        if(!is.null(object$colless))
-            cat("\tColless' index (colless)\n")
-        if(!is.null(object$gamma))
-            cat("\tGamma (gamma)\n")
-        if(!is.null(object$taxon))
-            cat("\tTaxonomic diversity (taxon)\n")
-        if(!is.null(object$eigen.sum))
-            cat("\tSum of dominant eigenvector (eigen.sum)\n")
-        if(!is.null(object$eed))
-            cat("\tEED (eed)\n")
-        if(!is.null(object$hed))
-            cat("\tHED (hed)\n")
-        if(!is.null(object$dist.fd))
-            cat("\tFunctional trait distance (dist.fd)\n")
-        cat("Use something like 'output$psv' to work with each measure\n")
-        cat("...or coef(output) to get a table of metric values\n")
-        return()
-    }
-    #Evenness
-    if(object$type == "evenness"){
-        cat("\nEvenness metrics in this object:\n")
-        if(!is.null(object$pse))
-            cat("\tPhylogenetic Species Evenness (pse)\n")
-        if(!is.null(object$rao))
-            cat("\tRao's quadratic entropy (rao)\n")
-        if(!is.null(object$taxon))
-            cat("\tTaxonomic diversity (taxon)\n")
-        if(!is.null(object$entropy))
-            cat("\tPhylogenetic entropy (entropy)\n")
-        if(!is.null(object$pae))
-            cat("\tPAC (pac)\n")
-        if(!is.null(object$iac))
-            cat("\tIAC (iac)\n")
-        if(!is.null(object$Haed))
-            cat("\tHaed (Haed)\n")
-        if(!is.null(object$Eaed))
-            cat("\tEaed (Eaed)\n")
-        if(!is.null(object$pst))
-            cat("\tPst - Simpson's diversity (pst)\n")
-        if(!is.null(object$lambda))
-            cat("\tLambda transformation (lambda)\n")
-        if(!is.null(object$delta))
-            cat("\tDelta transformation (delta)\n")
-        if(!is.null(object$kappa))
-            cat("\tKappa transformation (kappa)\n")
-        if(!is.null(object$mpd))
-            cat("\tMean Phylogenetic Distance (mpd)\n")
-        if(!is.null(object$mntd))
-            cat("\tMean Mean Nearest Taxon Distance (mntd)\n")
-        if(!is.null(object$dist.fd))
-            cat("\tFunctional trait distance (dist.fd)\n")
-        cat("Use something like 'output$rao' to work with each measure\n")
-        cat("...or coef(output) to get a table of metric values\n")
-        return()
-    }
-    #Dispersion
-    if(object$type == "dispersion"){
-        cat("\nDispersion metrics:\n")
-        if(!is.null(object$sesmpd)){
-            cat("\t SESmpd (sesmpd)\n")
-            print(object$sesmpd)
-        }
-        if(!is.null(object$sesmntd)){
-            cat("\tSESmntd (sesmntd)\n")
-            print(object$sesmntd)
-        }
-        if(!is.null(object$sespd)){
-            cat("\tSESpd (sespd)\n")
-            print(object$sespd)
-        }
-        if(!is.null(object$innd)){
-            cat("\tINND (innd)\n")
-            print(object$innd)
-        }
-        if(!is.null(object$d)){
-            cat("\tD (d)\n")
-            print(object$d)
-        }
-        cat("Use something like 'output$d' to work with each measure\n")
-        cat("...or coef(output) to get a table of metric values\n")
-        return()
-    }
-    #Dissimilarity
-    if(object$type == "dissimilarity"){
-        cat("\nDissimilarity metrics in this object:\n")
-        if(!is.null(object$unifrac))
-            cat("\tUniFrac (unifrac)\n")
-        if(!is.null(object$pcd))
-            cat("\tPCD (pcd)\n")
-        if(!is.null(object$phylosor))
-            cat("\tPhyloSor (phylosor)\n")
-        if(!is.null(object$comdist))
-            cat("\tComdist (comdist)\n")
-        cat("Use something like 'output$unifrac' to work with each measure\n")
-        return()
-    }
-    cat("No valid phylogenetic structure metrics found.\n")
-}
-
-#' @export
-print.phy.structure <- function(x, ...){
-    summary(x)
-}
-
-#' @method coef phy.structure
-#' @export
-coef.phy.structure <- function(object, ...){
-    #Shape
-    if(object$type == "dissimilarity")
-      cat("\nCannot produce a simple summary of dissimilarity matrices. Sorry.\n")
-    else
-      return(object$coefs)
-}
-
 .removeErrors <- function(object) {
     if(inherits(object, "try-error")) return(NULL)
     object
